@@ -32,14 +32,14 @@ public:
 	MessageReceiverTask(Task *parent);
 	~MessageReceiverTask();
 	
-	bool take(Transfer *transfer);
+	bool take(Transfer *transfer) Q_DECL_OVERRIDE;
 
 protected:
-	virtual bool forMe( const Transfer *transfer ) const;
+	bool forMe( const Transfer *transfer ) const Q_DECL_OVERRIDE;
 	void parseMessage( YMSGTransfer *transfer );
 	void parseAnimatedAudibleIcon( YMSGTransfer *transfer );
 	void parseNotify( YMSGTransfer *transfer );
-signals:
+Q_SIGNALS:
 	void gotIm(const QString&, const QString&, long, int);
 	void gotBuzz( const QString &who, long tm );
 	void systemMessage(const QString&);
